@@ -26,7 +26,6 @@ from yapf.yapflib import pytree_utils
 from yapf.yapflib import style
 
 CONTINUATION = token.N_TOKENS
-token.N_TOKENS += 1
 
 
 class Subtype(object):
@@ -93,6 +92,10 @@ class FormatToken(object):
       this is the first token in the unwrapped line.
     matching_bracket: If a bracket token ('[', '{', or '(') the matching
       bracket.
+    container_opening: If the object is in a container, this points to its
+      opening bracket.
+    container_elements: If this is the start of a container, a list of the
+      elements in the container.
     whitespace_prefix: The prefix for the whitespace.
     spaces_required_before: The number of spaces required before a token. This
       is a lower-bound for the formatter and not a hard requirement. For
@@ -118,6 +121,8 @@ class FormatToken(object):
     self.next_token = None
     self.previous_token = None
     self.matching_bracket = None
+    self.container_opening = None
+    self.container_elements = []
     self.whitespace_prefix = ''
     self.can_break_before = False
     self.must_break_before = False
@@ -218,7 +223,8 @@ class FormatToken(object):
     return self.value in pytree_utils.CLOSING_BRACKETS
 
   def __repr__(self):
-    msg = 'FormatToken(name={0}, value={1}'.format(self.name, self.value)
+    msg = 'FormatToken(name={0}, value={1}, lineno={2}'.format(
+        self.name, self.value, self.lineno)
     msg += ', pseudo)' if self.is_pseudo_paren else ')'
     return msg
 
@@ -300,13 +306,14 @@ class FormatToken(object):
   @property
   @py3compat.lru_cache()
   def is_multiline_string(self):
+    """A multiline string."""
     if py3compat.PY3:
-      prefix = "("
-      prefix += "r|u|R|U|f|F|fr|Fr|fR|FR|rf|rF|Rf|RF"  # strings
-      prefix += "|b|B|br|Br|bR|BR|rb|rB|Rb|RB"  # bytes
-      prefix += ")?"
+      prefix = '('
+      prefix += 'r|u|R|U|f|F|fr|Fr|fR|FR|rf|rF|Rf|RF'  # strings
+      prefix += '|b|B|br|Br|bR|BR|rb|rB|Rb|RB'  # bytes
+      prefix += ')?'
     else:
-      prefix = "[uUbB]?[rR]?"
+      prefix = '[uUbB]?[rR]?'
 
     regex = r'^{prefix}(?P<delim>"""|\'\'\').*(?P=delim)$'.format(prefix=prefix)
     return (self.is_string and
@@ -326,3 +333,8 @@ class FormatToken(object):
   def is_pylint_comment(self):
     return self.is_comment and re.match(r'#.*\bpylint:\s*(disable|enable)=',
                                         self.value)
+
+  @property
+  def is_pytype_comment(self):
+    return self.is_comment and re.match(r'#.*\bpytype:\s*(disable|enable)=',
+                                        self.value)
